unit USpacing;

//Source code based on old Fortran file

interface
  uses SysUtils, Dialogs, UDMEnDrain;
  var  RR,D1,D2,DW,DB,RE,WD,QA,QB1,QV1,QB2,QV2,DM : real;  {input var.}
       D1W, D21, DBW, DB1, WX, ZM : real;                  {help var.}
       InputError                 : boolean;
    QR1, QQ1, QR2, QQ2, DR1, DR2, DRT, BWR1, {B1R2} B1R1, DF, DG, PP, XX : real;
    XL, XH, YR, YH, YL, YRP, RES, FE, XS, YY, YZ, YI, YA, ZI, YN, ZN : real;
    TR, TRA, XC, DIF, T1, AY, T2, YJ, ZJ, T2P, XJ, Wtd, WTe : real;
    KK, NU :integer;
    OutputFile : textfile;
    OutFileName, InFileName : string;
  procedure CheckSpacingData;
  procedure Definitions;
  procedure WriteOutput;
  procedure DarSpac;
  procedure EneSpac;

implementation
  uses UMainForm;

procedure CheckSpacingData;
{-------------------------}
var InputFile, ErrorFile : textfile;
begin
  assignfile(InputFile,DMEnDrain.FileName);
  reset (InputFile);
  readln (InputFile);
  readln (InputFile);
  readln (InputFile);
  readln (InputFile);
  readln (InputFile,RR,D1,D2,DW,DB,RE,WD,QA,QB1,QV1,QB2,QV2,DM);
//RR=recharge, D1=depth of 1st layer, D2=depth of 2nd layer,
//DW=depth of waterlevel in drain, DB=depth of bottom of drain,
//RE=entrance resistance, WD=width of waterlvel in drain,
//Q=hydraulic conduvtivity, QA=horizontal Q of soil above drain level,
//QB1=horizontal Q of 1st layer, QV1 = vertical Q of 1st layer
//QB2=horizontal Q of 2nd layer, QV2 = vertical Q of 2nd layer
//DM=depth of waterlevel midway between drains
  closefile (InputFile);
//Data checks
  assignfile(ErrorFile,'Error.lst');
  rewrite (ErrorFile);
  writeln (ErrorFile,' THE FOLLOWING ERRORS WERE FOUND IN THE INPUT:');
  writeln (ErrorFile);
  InputError := false;
  if (RR<=0) then
  begin
    writeln (ErrorFile,' Make sure that R > 0.');
    InputError := true;
  end;
  D1W := D1 - DW;
  if (D1W<0) then
  begin
    writeln (ErrorFile,' Make sure that D1 > Dw.');
    InputError := true;
  end;
  D21 := D2 - D1;
  if (D21<0) then
  begin
    writeln (ErrorFile,' Make sure that D2 >= D1.');
    InputError := true;
  end;
  DBW := DB - DW;
  if (DBW<=0) then
  begin
    writeln (ErrorFile,' Make sure that Db > Dw.');
    InputError := true;
  end;
  DB1 := D1 - DB;
  if (RE<0) then
  begin
    writeln (ErrorFile,' Make sure that E >= 0.');
    InputError := true;
  end;
  WX := WD/2;
(* //Not necessary
  if (D21<>0) and (D1<DB+WX/2) and (D1>DB) then         {D21:=D2-D1}
  begin
    writeln (ErrorFile,' Make sure that D1 > Db+Wd/2 or D1 < Db.');
    InputError := true;
  end;
  if (D2>DB) and (D2<DB+WX/2) then
  begin
    writeln (ErrorFile,' Make sure that D2 < Db or D2 > Db+Wd/2.');
    InputError := true;
  end;
*)
  if (QA<=RR) then
  begin
    writeln (ErrorFile,' Make sure that Ka >= R.');
    InputError := true;
  end;
  if (QV1<=RR) then
  begin
    QB1 := 0;
    QB2 := 0;
  end;
  if (QV2<=RR) then QB2 := 0;
  ZM := DW - DM;
  if (ZM<=0) then
  begin
    writeln (ErrorFile,' Make sure that Dm < Dw.');
    InputError := true;
  end;
  if InputError then
  begin
    writeln (ErrorFile);
    writeln (ErrorFile, 'Please correct the errors.');
  end;
  closefile (ErrorFile);
end; {procedure CheckSpacingData}


Procedure Definitions;
{--------------------}
begin
  QQ1:=0;
  QQ2:=0;
  IF (QV1<=0) THEN QR1 := 1000000
  ELSE
  begin
    QR1:=sqrt(QB1/QV1);
    IF (QR1>0) then QQ1:=QB1/QR1;
  END;
  IF (QV2<=0) THEN QR2 := 1000000
  ELSE
  begin
    QR2:=sqrt(QB2/QV2);
    IF (QR2>0) then QQ2:=QB2/QR2;
  END;
  DR1:=D1W*QR1;
  DR2:=D21*QR2;
  DRT:=DR1+DR2;
  BWR1:=DBW*QR1;
//  B1R2:=DB1*QR2;
  B1R1:=DB1*QR1;
  IF (D1>DB) THEN
  begin
    DF:=WX-BWR1;
    IF (DF<0) then DF:=0;
    DG:=BWR1-WX;
    IF (DG<0) then DG:=0;
  end ELSE
  begin
    IF (D2>DB) THEN
    begin
//      DF:=WX-B1R2;
      DF:=WX-B1R1;
      IF (DF<0) then DF:=0;
//      DG:=B1R2-WX;
      DG:=B1R1-WX;
      IF (DG<0) then DG:=0;
    END else
    begin
      WX:=0;
      DF:=0;
//      DG:=B1R2;
      DG:=B1R1;
      IF (DG<0) then DG:=0
    END;
  END;
  PP:=0.01;
  KK:=1+round(WX/PP);
  IF (KK<2) then KK:=2;
  XL:=WX;
  XH:=1000;
  XX:=WX;
  if DW-DM<0.2 then
  begin
    PP:=0.0001;
    XX:=0.01;
    Showmessage (' Dw-Dm is less than 0.2. The drain spacing will be short.');
  end;
  YL:=0;
  YRP:=0;
  RES:=0.0001;
  ZI:=0;
  YI:=0;
end; {procedure Definitions}


procedure WriteOutput;
{--------------------}
label 1, 2;
var LL, IJ, II, NN, MM, JL, KL : integer;

begin
//preparing output data, initial values
  LL:=round(XX/10);
  YL:=LL;
  PP:=0.00001;
  LL:=Round(YL/PP);
  IF (LL<1) then LL:=round(XX/PP);
  KK:=1+round(WX/PP);
  IF (KK<2) then KK:=2;
  NU:=round(XX/PP);
  NN:=0;
  MM:=0;
  YJ:=0;
  YN:=0;
  ZN:=0;
  ZJ:=0;
  T2:=-1;

//preparing output data for energy balance and Darcy
  for JL:=KK to NU do
  begin

//output data for energy balance
    XS:=PP*(JL-0.5);                                  //XS =distance from drain
    YY:=1.571*XS;
    YZ:=YY+DG;                                        //DG:=BWR1-WX;
// WX:=WD/2; BWR1:=DBW*QR1; DBW:=DB-DW; QR1:=sqrt(QB1/QV1);
    IF (JL=KK) THEN
    begin
      YJ:=FE;
      YA:=FE;
    end ELSE
      YA:=YJ+0.5*ZJ*PP;                                  //YA is WT level at XS
    IF (D1>DB) THEN
    begin
      TR:=QA*YA+QV1*DF;
      TRA:=TR+QQ1*YZ;                                    //QQ1:=QB1/QR1;
// DF:=WX-BWR1; WX:=WD/2; BWR1:=DBW*QR1; DBW:=DB-DW; QR1:=sqrt(QB1/QV1);
      IF (YZ>DR1) then TRA:=TR+QQ1*DR1+QQ2*(YZ-DR1);
//DR1:=D1W*QR1; D1W:=D1-DW;
      IF (YZ>DRT) then TRA:=TR+QQ1*DR1+QQ2*DR2;
//QQ2=QB2/QR2; QR2:=sqrt(QB2/QV2); DR2:=D21*QR2; D21:=D2-D1; QR2:=sqrt(QB2/QV2);
    end ELSE
      IF (D2<=DB) THEN
         TRA:=QA*YA+QB1*D1W+QB2*D21
      ELSE
      begin
        TR:=QA*YA+QB1*D1W+QV2*DF;
        TRA:=TR+QQ2*YZ ;
        IF (YZ>DR2) then TRA:=TR+QQ2*DR2;
      END;
    XC:=XX-XS;                                        //XX = half drain spacing
    T1:=RR*XC/TRA;
    AY:=YA-YR;                            //YR = midway WT level energy balance
    T2P:=T2;
    T2:=AY/XC;
    ZJ:=T1+T2;
    IF (JL>KK) THEN
    BEGIN
      IF (ZJ<0) OR (T2>0) then
      begin
        ZJ:=T1;
        T2:=0;
      end;
      IF (T2<T2P) then
      begin
        ZJ:=T1;
        T2:=0.5*T2P;
      END;
    END;
    YJ:=YJ+ZJ*PP;

//output data for Darcy
    IF (JL=KK) THEN
    begin
      YN:=FE;
      YA:=FE;
    end ELSE
      YA:=YN+0.5*ZN*PP;
    IF (D1>DB) THEN
    begin
      TR:=QA*YA+QV1*DF;
      TRA:=TR+QQ1*YZ;
      IF (YZ>DR1) then TRA:=TR+QQ1*DR1+QQ2*(YZ-DR1);
      IF (YZ>DRT) then TRA:=TR+QQ1*DR1+QQ2*DR2;
    end ELSE
    begin
      IF (D2<=DB) THEN
         TRA:=QA*YA+QB1*D1W+QB2*D21
      ELSE
      begin
        TR:=QA*YA+QB1*D1W+QV2*DF;
        TRA:=TR+QQ2*YZ;
        IF (YZ>DR2) then TRA:=TR+QQ2*DR2;
      END;
    end;
    ZN:=RR*XC/TRA;
    YN:=YN+ZN*PP;

//Determining when to write output data
    XJ:=JL*PP;
    KL:=0;
    if YN<0.0001 then YN:=0.0001;
    if YJ<0.0001 then YJ:=0.0001;
    while KL<=NU do
    begin
      IF (MM=0) AND (JL=KL/4) THEN
      begin
        MM:=1;
        GOTO 1;
      END;
      IF (NN=0) AND (JL=KL/2) THEN
      begin
        NN:=1;
        GOTO 1;
      END;
      IF (JL=KL) then GOTO 1;
      IF (JL=KK) AND (KK<>KL) then GOTO 1;
      IF (JL=NU) AND (NU<>KL) then GOTO 1;
      inc(KL,LL);
    end; {while KL<=LL do}
    goto 2;
    if YN<0.0001 then YN := 0.0001;
    if YJ<0.0001 then YJ := 0.0001;
1:  WRITELN (OutputFile, XJ:6:2,YN:10:4,ZN:10:4,YJ:10:4,ZJ:10:4,
                            T1:10:4,T2:10:4);
2:end; {for JL:=KK to NU do}

end; {procedure WriteOutput}


procedure DarSpac;
{----------------}
label 1, 2, 3, 4, 5;
var LL, IJ, II, NN, MM, JL, KL : integer;
begin
  InFileName:=DMEnDrain.FileName;
  OutFileName:=changefileext (DMEnDrain.FileName,'.out');
  assignfile(OutputFile,OutFileName);
  rewrite (OutputFile);
  writeln (OutputFile);
  writeln (OutputFile,' EnDrain, by R.J.Oosterbaan');
  writeln (OutputFile,' Program DarSpac calculates the drain spacing'+
                      ' using the Darcy equation.');
  writeln (OutputFile,' It also calculates the shape of the watertable'+
                      ' for two cases:');
  writeln (OutputFile,' (1) Darcy, and (2) the energy balance.');
  writeln (OutputFile,' The program allows the introduction of 3 soil layers'+
                      ' with');
  writeln (OutputFile,' anisotropic hydraulic conductivity.');
  writeln (OutputFile,' Calculations can be made for pipe drains or ditches');
  writeln (OutputFile,' with or without entrance resistance.');
  writeln (OutputFile);
  writeln (OutputFile,'  ',DMEnDrain.Title1);
  writeln (OutputFile,'  ',DMEnDrain.Title2);
  writeln (OutputFile);
  writeln (OutputFile,' Name of input file used:  ',InFileName);
  writeln (OutputFile,' Name of this output file: ',OutFileName);
  writeln (OutputFile);
  writeln (OutputFile,' DarSpac input data: ');
  writeln (OutputFile);
  writeln (OutputFile,' Time average recharge or discharge'+
                      '         R    (m/day) :  ',RR:10:4);
  writeln (OutputFile,' Bottom depth of 1st layer below s.s.'+
                      '       D1       (m) :  ',D1:10:2);
  writeln (OutputFile,' Bottom depth of 2nd layer below s.s.'+
                      '       D2       (m) :  ',D2:10:2);
  writeln (OutputFile,' Depth waterlevel in drain below s.s.'+
                      '       Dw       (m) :  ',DW:10:2);
  writeln (OutputFile,' Depth of drain bottom below s.s.'+
                      '           Db       (m) :  ',DB:10:2);
  writeln (OutputFile,' Entrance resistance at the drain'+
                      '           E    (day/m) :  ',RE:10:3);
  writeln (OutputFile,' Max. width of water body in the drain'+
                      '      W        (m) :  ',WD:10:3);
  writeln (OutputFile,' Hydraulic permeability, above drain level'+
                      '  Ka   (m/day) :  ',QA:10:3);
  writeln (OutputFile,' Horizontal permeability, 1st soil layer'+
                      '    Kb1  (m/day) :  ',QB1:10:3);
  writeln (OutputFile,' Vertical permeability, 1st soil layer'+
                      '      Kv1  (m/day) :  ',QV1:10:4);
  writeln (OutputFile,' Horizontal permeability, 2nd soil layer'+
                      '    Kb2  (m/day) :  ',QB2:10:3);
  writeln (OutputFile,' Vertical permeability, 2nd soil layer'+
                      '      Kv2  (m/day) :  ',QV2:10:4);
  writeln (OutputFile,' Depth watertable midway between drains'+
                      '     Dm       (m) :  ',DM:10:2);
  writeln (OutputFile);
  writeln (OutputFile,' Watertable heights (see also the Symbols button):');
  writeln (OutputFile,'   X       F*        G*/p      F         G/p'+
                      '       T1        T2');
  writeln (OutputFile,' Output data:');

  Definitions;

//Calculating spacing Darcy
1:NU:=round(XX/PP);
  for IJ:=KK to NU do
  begin
    XS:=PP*(IJ-0.5);                                  //XS =distance from drain
    YY:=1.571*XS;
    YZ:=YY+DG;
    FE:=2*RR*XX*RE;
    IF (IJ=KK) THEN
    BEGIN
      YI:=FE;
      YA:=FE;
    END ELSE
      YA:=YI+0.5*ZI*PP;                                  //YA is WT level at XS
    IF (D1>DB) THEN
    begin
      TR:=QA*YA+QV1*DF;
// DF:=WX-BWR1; WX:=WD/2; BWR1:=DBW*QR1; DBW:=DB-DW; QR1:=sqrt(QB1/QV1);
      TRA:=TR+QQ1*YZ;                                    //TRA = transmissivity
      IF (YZ>DR1) then TRA:=TR+QQ1*DR1+QQ2*(YZ-DR1);     //QQ1:=QB1/QR1;
//DR1:=D1W*QR1; D1W:=D1-DW;
      IF (YZ>DRT) then TRA:=TR+QQ1*DR1+QQ2*DR2;
//QQ2=QB2/QR2; QR2:=sqrt(QB2/QV2); DR2:=D21*QR2; D21:=D2-D1; QR2:=sqrt(QB2/QV2);
    end ELSE
      IF (D2<=DB) THEN
         TRA:=QA*YA+QB1*D1W+QB2*D21
      ELSE
      begin
         TR:=QA*YA+QB1*D1W+QV2*DF;
         TRA:=TR+QQ2*YZ;
         IF (YZ>DR2) then TRA:=TR+QQ2*DR2;
      END;
   XC:=XX-XS;
   ZI:=RR*XC/TRA;
   YI:=YI+ZI*PP;
  end; {for IJ:=KK to NU do}

  DIF:=ABS(YI-ZM);
  IF (DIF<RES) then GOTO 2;
  IF (YI<ZM) THEN
  begin
    XL:=XX;
    XX:=0.5*(XX+XH);
  end ELSE
  begin
    XH:=XX;
    XX:=0.5*(XX+XL);
  END;
  GOTO 1;

//Calculating WT depth Energy (YR or YZ)
2:YR:=500;
  YH:=1000;
  YL:=0;
  YRP:=0;
  FE:=2*RR*XX*RE;
3:for II:=KK to NU do
  begin
    XS:=PP*(II-0.5);                                  //XS =distance from drain
    YY:=1.571*XS;
    YZ:=YY+DG;
    IF (II=KK) THEN
    BEGIN
      YI:=FE;
      YA:=FE;
    END ELSE
      YA:=YI+0.5*ZI*PP;                                  //YA is WT level at XS
    IF (D1>DB) THEN
    begin
      TR:=QA*YA+QV1*DF;
      TRA:=TR+QQ1*YZ;
      IF (YZ>DR1) then TRA:=TR+QQ1*DR1+QQ2*(YZ-DR1);
      IF (YZ>DRT) then TRA:=TR+QQ1*DR1+QQ2*DR2;
    end ELSE
    begin
      IF (D2<=DB) THEN
         TRA:=QA*YA+QB1*D1W+QB2*D21
      ELSE
      begin
         TR:=QA*YA+QB1*D1W+QV2*DF;
         TRA:=TR+QQ2*YZ;
         IF (YZ>DR2) then TRA:=TR+QQ2*DR2;
      END;
    end;
    XC:=XX-XS;
    T1:=RR*XC/TRA;
    AY:=YA-YR;
    T2:=AY/XC;
    ZI:=T1+T2;
    YI:=YI+ZI*PP;
    IF (YI>YR) OR (ZI<0) then GOTO 4;
  end; { For II:=KK to NU do}

4:DIF:=ABS(YRP-YR);
  IF (DIF<RES) then GOTO 5;
  YRP:=YR;                      //final YI=YR is midway WT level energy balance
  IF (YI>YR) THEN
  begin
    YL:=YR;
    YR:=(YR+YH)/2;
  end ELSE
  begin
    YH:=YR;
    YR:=(YR+YL)/2;
  END;
  GOTO 3;

5:WriteOutput;
  writeln (OutputFile,' #');
  XL:=2*XL;
  WTd := DW-YN;
  WTe := DW-YR;
  writeln (OutputFile,' The drain spacing (Darcy,  m) is: ',XL:8:2);
  writeln (OutputFile);
  writeln (OutputFile,' Midway hydr. head (Darcy,  m) is: ',YN:8:3);
  writeln (OutputFile,' Midway hydr. head (energy, m) is: ',YJ:8:3);
  writeln (OutputFile,' Midway W.T. depth (Darcy,  m) is: ',WTd:8:3);
  writeln (OutputFile,' Midway W.T. depth (energy, m) is: ',WTe:8:3);
  writeln (OutputFile,' #');
  closefile (OutputFile);

end; {procedure DarSpac}



procedure EneSpac;
{----------------}
label 1, 2, 3, 4, 5;
var IJ : integer;
    Passed : boolean;

begin
  InFilename:=DMEnDrain.FileName;
  OutFileName:=changefileext (InFilename,'.out');
  assignfile(OutputFile,OutFileName);
  rewrite (OutputFile);
  writeln (OutputFile,' EnDrain, by R.J.Oosterbaan');
  writeln (OutputFile,' Program EneSpac calculates the drain spacing'+
                      ' using the energy');
  writeln (OutputFile,' balance equation.');
  writeln (OutputFile,' It also calculates the shape of the watertable'+
                      ' for two cases:');
  writeln (OutputFile,' (1) Darcy, and (2) the energy balance.');
  writeln (OutputFile,' The program allows the introduction of 3 soil layers'+
                      ' with');
  writeln (OutputFile,' anisotropic hydraulic conductivity.');
  writeln (OutputFile,' Calculations can be made for pipe drains or ditches');
  writeln (OutputFile,' with or without entrance resistance.');
  writeln (OutputFile);
  writeln (OutputFile,'  ',DMEnDrain.Title1);
  writeln (OutputFile,'  ',DMEnDrain.Title2);
  writeln (OutputFile);
  writeln (OutputFile,' Name of input file used:  ',InFileName);
  writeln (OutputFile,' Name of this output file: ',OutFileName);
  writeln (OutputFile);
  writeln (OutputFile,' EneSpac input data: ');
  writeln (OutputFile);
  writeln (OutputFile,' Time average recharge or discharge'+
                      '         R    (m/day) :  ',RR:10:4);
  writeln (OutputFile,' Bottom depth of 1st layer below s.s.'+
                      '       D1       (m) :  ',D1:10:2);
  writeln (OutputFile,' Bottom depth of 2nd layer below s.s.'+
                      '       D2       (m) :  ',D2:10:2);
  writeln (OutputFile,' Depth waterlevel in drain below s.s.'+
                      '       Dw       (m) :  ',DW:10:2);
  writeln (OutputFile,' Depth of drain bottom below s.s.'+
                      '           Db       (m) :  ',DB:10:2);
  writeln (OutputFile,' Entrance resistance at the drain'+
                      '           E    (day/m) :  ',RE:10:3);
  writeln (OutputFile,' Max. width of water body in the drain'+
                      '      W        (m) :  ',WD:10:3);
  writeln (OutputFile,' Hydraulic permeability, above drain level'+
                      '  Ka   (m/day) :  ',QA:10:3);
  writeln (OutputFile,' Horizontal permeability, 1st soil layer'+
                      '    Kb1  (m/day) :  ',QB1:10:3);
  writeln (OutputFile,' Vertical permeability, 1st soil layer'+
                      '      Kv1  (m/day) :  ',QV1:10:4);
  writeln (OutputFile,' Horizontal permeability, 2nd soil layer'+
                      '    Kb2  (m/day) :  ',QB2:10:3);
  writeln (OutputFile,' Vertical permeability, 2nd soil layer'+
                      '      Kv2  (m/day) :  ',QV2:10:4);
  writeln (OutputFile,' Depth watertable midway between drains'+
                      '     Dm       (m) :  ',DM:10:2);
  writeln (OutputFile);
  writeln (OutputFile,' Watertable heights (see also the Symbols button):');
  writeln (OutputFile,'   X       F*        G*/p      F         G/p'+
                      '       T1        T2');
  writeln (OutputFile,' Output data:');

  Definitions;
  Passed:=false;
//Calculating spacing Energy balance

1:YR:=500;
  YH:=1000;
  YL:=0;
  YRP:=0;
  ZI:=0;
  YI:=0;

//Calculating spacing Energy balance
2:NU:=round(XX/PP);
  for IJ:=KK to NU do
  begin
    XS:=PP*(IJ-0.5);                                  //XS =distance from drain
    YY:=1.571*XS;
    YZ:=YY+DG;
    FE:=2*RR*XX*RE;
    IF (IJ=KK) THEN
    BEGIN
      YI:=FE;
      YA:=FE;
    END ELSE
      YA:=YI+0.5*ZI*PP;                                  //YA is WT level at XS
    IF (D1>DB) THEN
    begin
      TR:=QA*YA+QV1*DF;                                  //TRA = transmissivity
      TRA:=TR+QQ1*YZ;
      IF (YZ>DR1) then TRA:=TR+QQ1*DR1+QQ2*(YZ-DR1);
      IF (YZ>DRT) then TRA:=TR+QQ1*DR1+QQ2*DR2;
    end ELSE
      IF (D2<=DB) THEN
         TRA:=QA*YA+QB1*D1W+QB2*D21
      ELSE
      begin
         TR:=QA*YA+QB1*D1W+QV2*DF;
         TRA:=TR+QQ2*YZ;
         IF (YZ>DR2) then TRA:=TR+QQ2*DR2;
      END;
    XC:=XX-XS;
    T1:=RR*XC/TRA;
    AY:=YA-YR;
    T2:=AY/XC;
    ZI:=T1+T2;
    YI:=YI+ZI*PP;
    IF (YI>YR) OR (ZI<0) then GOTO 3;
  end; { For IJ:=KK to NU do}
3:DIF:=ABS(YRP-YR);
  IF (DIF<RES) then GOTO 4;
  YRP:=YR;                      //final YI=YR is midway WT level energy balance
  IF (YI>YR) THEN
  begin
    YL:=YR;
    YR:=(YR+YH)/2;
  end ELSE
  begin
    YH:=YR;
    YR:=(YR+YL)/2;
  END;
  GOTO 2;

4:DIF:=ABS(YI-ZM);
  if not Passed and (DIF<100*RES) then
  begin
     MainForm.WaitMemo.Lines.Add(' Still working ...');
     Passed:=true;
  end;
  IF (DIF<RES) then GOTO 5;
  IF (YR<ZM) THEN
  begin
    XL:=XX;
    XX:=0.5*(XX+XH);
  end ELSE
  begin
    XH:=XX;
    XX:=0.5*(XX+XL);
  END;
  GOTO 1;

5:WriteOutput;
  writeln (OutputFile,' #');
  XL:=2*XL;
  WTd := DW-YN;
  WTe := DW-YI;
  writeln (OutputFile,' The drain spacing (energy, m) is: ',2*XX:8:2);
  writeln (OutputFile);
  writeln (OutputFile,' Midway hydr. head (energy, m) is: ',YI:8:3);
  writeln (OutputFile,' Midway hydr. head (Darcy,  m) is: ',YN:8:3);
  writeln (OutputFile,' Midway W.T. depth (energy, m) is: ',WTe:8:3);
  writeln (OutputFile,' Midway W.T. depth (Darcy,  m) is: ',WTd:8:3);
  writeln (OutputFile,' #');
  closefile (OutputFile);

end; {Procedure EneSpac}


end.

